@@ -5,16 +5,20 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
-module Backend.URL (backend) where
+module Backend.URL (backends) where
 
 import Control.Monad.State (liftIO)
-import Data.String.Utils
 
-import TypeInternals
+import Types
+import BackendClass
 import Utility
 import Messages
+import Key
 
-backend :: Backend
+backends :: [Backend Annex]
+backends = [backend]
+
+backend :: Backend Annex
 backend = Backend {
 	name = "URL",
 	getKey = keyValue,
@@ -26,7 +30,9 @@ backend = Backend {
 	-- similarly, keys are always assumed to be out there on the web
 	hasKey = dummyOk,
 	-- and nothing needed to fsck
-	fsckKey = dummyFsck
+	fsckKey = dummyFsck,
+	-- and key upgrade not needed
+	upgradableKey = \_ -> return False
 }
 
 -- cannot generate url from filename
@@ -38,18 +44,18 @@ dummyStore :: FilePath -> Key -> Annex Bool
 dummyStore _ _ = return False
 
 dummyRemove :: Key -> Maybe a -> Annex Bool
-dummyRemove _ _ = return False
+dummyRemove _ _ = return True
 
-dummyFsck :: Key -> Maybe a -> Annex Bool
-dummyFsck _ _ = return True
+dummyFsck :: Key -> Maybe FilePath -> Maybe a -> Annex Bool
+dummyFsck _ _ _ = return True
 
 dummyOk :: Key -> Annex Bool
 dummyOk _ = return True
 
 downloadUrl :: Key -> FilePath -> Annex Bool
 downloadUrl key file = do
-	showNote "downloading"
+	showNote $ "downloading"
 	showProgress -- make way for curl progress bar
-	liftIO $ boolSystem "curl" ["-#", "-o", file, url]
+	liftIO $ boolSystem "curl" [Params "-# -o", File file, File url]
 	where
-		url = join ":" $ drop 1 $ split ":" $ show key 
+		url = keyName key
